from .lib.parse import Parse
import argparse
import sys

def argument():
    if len(sys.argv) == 1:
        sys.argv.append("--help")
    parser = argparse.ArgumentParser(description="This is a command to check if crawls are allowed for URL.  Also, you can also get the Allow list and Disallow list by using the option")
    parser.add_argument("URL", help="URL you want to crawl")
    parser.add_argument("-u", "--user-agent", default="*", help="User-agent you want to check")
    parser.add_argument("-a", "--allow", action="store_true", help="Ouptut the Allow list")
    parser.add_argument("-d", "--disallow", action="store_true", help="Output the Disallow list")
    parser.add_argument("-c", "--crawl-delay", action="store_true", help="Output the Crawl-delay")
    return parser.parse_args()

def main():
    args = argument()
    p = Parse(args.URL)
    if args.allow is args.disallow is args.crawl_delay is False:
        if p.can_crawl(args.URL, useragent=args.user_agent):
            print("Y")
        else:
            print("N")
    else:
        if args.allow:
            allow = p.Allow(args.user_agent)
            if allow:
                print("\n".join(allow))
        if args.disallow:
            disallow = p.Disallow(args.user_agent)
            if disallow:
                print("\n".join(disallow))
        if args.crawl_delay:
            print(p.delay(args.user_agent))

if __name__ == "__main__":
    main()


from .error import UserAgentExistsError

class Make:
    def __init__(self):
        self._useragent = {}
        self._sitemap = []

    def add_useragent(self, useragent="*"):
        if isinstance(useragent, str):
            if useragent in self._useragent:
                raise UserAgentExistsError(f"{useragent} already exists")
            instance = UserAgent()
            self._useragent[useragent] = instance
            return instance
        else:
            raise ValueError("useragent must be str")

    def add_sitemap(self, url):
        if isinstance(url, (list, set, tuple)):
            self._sitemap.extend(list(url))
        elif isinstance(url, str):
            self._sitemap.append(url)
        else:
            raise ValueError("url must be str or list or set or tuple")

    def make(self):
        text = ""
        for useragent, instance in self._useragent.items():
            value = "\nUser-agent: {}\n".format(useragent)
            if instance.disallow:
                value += "{}\n".format("Disallow: "+"\nDisallow: ".join(instance.disallow))
            if instance.allow:
                value += "{}\n".format("Allow: "+"\nAllow: ".join(instance.allow))
            text += value
        if self._sitemap:
            text += "\nSitemap: " + "\nSitemap: ".join(self._sitemap)
        return text.strip()

    def to_file(self, path):
        info = self.make()
        with open(path, "w") as f:
            f.write(info)

class UserAgent:
    def __init__(self):
        self.disallow = []
        self.allow = []
    def add_disallow(self, disallow):
        if isinstance(disallow, (list, set, tuple)):
            self.disallow.extend(list(disallow))
        elif isinstance(disallow, str):
            self.disallow.append(disallow)
        else:
            raise ValueError("disallow must be str or list or set or tuple")
    def add_allow(self, allow):
        if isinstance(allow, (list, set, tuple)):
            self.allow.extend(list(allow))
        elif isinstance(allow, str):
            self.allow.append(allow)
        else:
            raise ValueError("allow must be str or list or set or tuple")